﻿© Fluke. All Rights Reserved.                               MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub FSV Compute Freq Response Reference Uncertainty
INSTRUMENT:            Sub FSV Compute Freq Response Test Uncertainty
DATE:                  2011-08-04
AUTHOR:                Fluke Calibration
REVISION:              $Revision: 2619 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       112
=============================================================================
#
#  Procedure Author:
#        DFM
#
#  Model(s) Covered:
#        Various FSV models
#
#  Compatibility:
#        MET/CAL 7.3 SP1 (7.3.36) or later
#
#  Subprocedures:
#        None
#
#  Required Files:
#        11667a.acc
#        4419.acc
#
#  Additional Equipment Required:
#        None
#
#  Frequency Response (301 MHz to 6.999 GHz) is computed using the following:
#   The uncertainties shown in the following ACC statements (stated at k=2)
#   were computed including the following components:
#     1. E4419() Instrumentation Accuracy during characterization
#     2. 8481A Power Sensor Cal Factor Uncertainty during characterization
#     3. 8481A to Power Sensor Mismatch Uncertainty during characterization
#     4. 8481A Noise Floor Specification during verification
#     5. Power Splitter to UUT Mismatch Uncertainty during verification
#
#   Note that the SWR values used computing mismatch uncertainty, both during
#   characterization and verification, are taken directly from manufacturer's
#   published specifications (worst case), not actual measured values.
#
#   It should be noted that although the first three uncertainty components
#   occur during characterization, the inclusion of them during computation
#   occurs during the verification process, in addition to those actually
#   incurred during verification.
#
#  The copyright for this procedure is owned by Fluke Corporation.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

# The following are for uncertainties incurred during characterization.
  1.001  MATH         Freq = BASE(@TestFreq)
# Retrieve Power Sensor input SWR at test frequency.
  1.002  MATH         @LoadSWR = ACCV(@DevName1, @SensorSWR_Mode, Freq)
# Retrieve Power Splitter (output port) SWR at test frequency.
  1.003  MATH         @SourceSWR = ACCV(@DevName2, @SpltrSWR_Mode, Freq)
# Compute normalized mismatch uncertainty (Splitter to Sensor), Port 1.
  1.004  CALL         Sub Compute Mismatch Uncertainty (%)
  1.005  MATH         L[1] = @MismatchUncPct

  1.006  IF           PSUBI("Reference")
# The following are for uncertainties incurred during verification.
  1.007  MATH         @LoadSWR = @UUT_SWR
# Compute normalized mismatch uncertainty (Splitter to UUT), Port 1.
  1.008  CALL         Sub Compute Mismatch Uncertainty (%)
  1.009  MATH         L[2] = @MismatchUncPct
# Instrumentation (Absolute Power) Accuracy of E4419() in percent.
  1.010  MATH         L[3] = 0.5 / SQRT(3)
# Sensor/Splitter mismatch, incurred during characterization, combined with
# mismatch uncertainty (Splitter to UUT), incurred during verification, and
# E4419() Instrumentation Accuracy, incurred during characterization.
  1.011  MATH         RelAcc = RSS_L(1, 3)
  1.012  ELSE
# Sensor/Splitter mismatch, incurred during characterization, combined with
# noise (instability) of 8481A in percent, incurred during verification.
  1.013  MATH         L[2] = @Floor
  1.014  MATH         RelAcc = RSS_L(1, 2)
  1.015  ENDIF

  1.016  IF           (BASE(@TestFreq) > 64E+6)

# 8481A Cal Factor Uncertainties (percent, taken from Agilent data sheet).
  1.017  IF           (BASE(@TestFreq) < 1.2E+9)
  1.018  MATH         CalFacUnc = 0.78
  1.019  ELSEIF       (BASE(@TestFreq) < 6E+9)
  1.020  MATH         CalFacUnc = 0.92
  1.021  ELSEIF       (BASE(@TestFreq) < 14E+9)
  1.022  MATH         CalFacUnc = 1.16
  1.023  ELSEIF       (BASE(@TestFreq) < 18E+9)
  1.024  MATH         CalFacUnc = 1.59
  1.025  ENDIF

  1.026  ENDIF

  1.027  IF           PSUBI("Reference")
# Store combined uncertainty (%) of 64 MHz reference set on UUT.
  1.028  MATH         @RefUnc = RelAcc
  1.029  ELSE
# RSS mismatch/floor uncertainties with (normalized) Cal Factor uncertainty.
  1.030  MATH         TestUnc = RSS2(RelAcc, (CalFacUnc / 2))
# Combine reference and test uncertainties (%) and convert to dB relative.
  1.031  MATH         M[1] = PCTTODBW_D(RSS2(@RefUnc, TestUnc) * 2)
  1.032  ENDIF

  1.033  END
