﻿© Fluke. All Rights Reserved.                               MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub FSV Set Ref Level (dBm) /SWPG
DATE:                  2011-08-08
AUTHOR:                Fluke Calibration
REVISION:              $Revision: 2619 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       104
CONFIGURATION:         Sweep Generator
=============================================================================
#
#  Procedure Author:
#        DFM
#
#  Model(s) Covered:
#        Rohde & Schwarz FSV series
#
#  Compatibility:
#        MET/CAL 7.3 SP1 (7.3.36) or later
#
#  Subprocedures:
#        Sub Apply /SWPG
#        Sub FSV Take Sweep (MKPK)
#        Sub FSV Display Connection
#
#  Required Files:
#        None
#
#  Additional Equipment Required:
#        None
#
#  The necessary parameters for this procedure are passed from the calling
#   procedure.
#
#   @RefLvl     : The desired reference level as measured by the UUT (FSV).
#   @TestLvl    : The SWPG output level required to generate the specified
#                 reference level.
#   @HiLimit    : The upper limit of the setting aperture (in dBm).
#   @LoLimit    : The lower limit of the setting aperture (in dBm).
#
#                (The SWPG output frequency is previously set in the calling
#                 procedure.)
#
#  Example:
# 1.001  SCPI         CALC:MARK:Y?[I]
# 1.002  MATH         @RefLvl = 0; @TestLvl = -4
# 1.003  MATH         @LoLimit = -0.05; @HiLimit = 0.05
# 1.004  CALL         Sub FSV Set Ref Level (dBm) /SWPG
#
# The copyright for this procedure is owned by Fluke Corporation.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

  1.001  IF           0
  1.002  IEEE         [@SWPG]
  1.003  ENDIF

  1.004  MATH         MaxRetries = 5

  1.005  DO
  1.006  MATH         Count = 0; Retry = 1

  1.007  WHILE        ((MEM <= @LoLimit) || (MEM >= @HiLimit)) && Retry
  1.008  MATH         Delta = (@RefLvl - MEM)
  1.009  MATH         @TestLvl = @TestLvl + Delta
  1.010  MATH         @SWPG_Ampl = @TestLvl & "dBm"
  1.011  CALL         Sub Apply /SWPG
  1.012  CALL         Sub FSV Take Sweep (MKPK)
  1.013  SCPI         CALC:MARK:Y?[I]
  1.014  MATH         Count = Count + 1; Retry = (Count <= MaxRetries)
  1.015  ENDW

  1.016  MATH         @Error = (Count > (MaxRetries + 1))

  1.017  IF           @Error
  1.018  OPBR         -z Error: Unable to adjust the Sweep Generator output
  1.018  OPBR         [32]      level within its operating range to achieve
  1.018  OPBR         [32]      the desired test level ([V @RefLvl] dBm).
  1.018  OPBR
  1.018  OPBR         [32]      Verify UUT test requirements, SWPG output
  1.018  OPBR         [32]      limits, and connections prior to retrying,
  1.018  OPBR         [32]      if desired.
  1.018  OPBR
  1.018  OPBR         Do you wish to RETRY?
  1.018  OPBR
  1.018  OPBR         (Selecting "No" will cause the [V @TestName] test
  1.018  OPBR         to be terminated.)
  1.019  MATH         @Error = NOT(MEM1)

  1.020  IF           MEM1
  1.021  CALL         Sub FSV Display Connection
  1.022  MATH         @TestLvl = @RefLvl; MEM = @RefLvl
  1.023  ENDIF

  1.024  ENDIF

  1.025  UNTIL        ((MEM >= @LoLimit) && (MEM <= @HiLimit)) || @Error

  1.026  END
